from __future__ import annotations

from .ara.ArEntail import *
from .ces.CTKFactsNLI import *
from .dan.TalemaaderPC import *
from .deu.FalseFriendsDeEnPC import *
from .eng.LegalBenchPC import *
from .eng.PubChemAISentenceParaphrasePC import *
from .eng.PubChemSMILESPC import *
from .eng.PubChemSynonymPC import *
from .eng.PubChemWikiParagraphsPC import *
from .eng.SprintDuplicateQuestionsPC import *
from .eng.TwitterSemEval2015PC import *
from .eng.TwitterURLCorpusPC import *
from .fas.FaMTEBPairClassification import *
from .fas.FarsTail import *
from .hye.ArmenianParaphrasePC import *
from .ind.IndoNLI import *
from .ita.DisCoTexPairClassification import *
from .kor.KlueNLI import *
from .multilingual.OpusparcusPC import *
from .multilingual.PawsXPairClassification import *
from .multilingual.PubChemWikiPairClassification import *
from .multilingual.RTE3 import *
from .multilingual.XNLI import *
from .multilingual.XStance import *
from .pol.PolishPC import *
from .por.Assin2RTE import *
from .por.SickBrPC import *
from .rus.TERRa import *
from .vie.SprintDuplicateQuestionsPCVN import *
from .vie.TwitterSemEval2015PCVN import *
from .vie.TwitterURLCorpusPCVN import *
from .zho.CMTEBPairClassification import *
